Module logical

Module logical 

Structs

Aggregation
Argument
Create
Delete
Expand
Filter
Limit
LogicalPlan
Merge
NodeScan
OptionalMatch
Left-outer-join style node: runs the inner sub-plan for each input row. If no rows are produced, emits one row with nulls for the new variables.
PathBuild
Assembles a path value from matched node and relationship VarIds.
Projection
Remove
Set
Sort
Unwind

Enums

LogicalOp

Type Aliases

PlanNodeId